<?php
namespace Ep\Form\Helper;

use Indigo\View\Helper\Indent;
use Zend\Form\Element\MultiCheckbox;
use Zend\Form\ElementInterface;
use Zend\Form\LabelAwareInterface;
use Zend\Form\View\Helper\FormMultiCheckbox as BaseFormMultiCheckbox;

class FormMultiCheckbox extends BaseFormMultiCheckbox
{
	/**
	 * Helper za indentaciju.
	 *
	 * @var Indent
	 */
	protected $indentHelper;

	/**
	 * Vraća helper za indentaciju.
	 *
	 * @return Indent
	 */
	protected function getIndentHelper()
	{
		if (null === $this->indentHelper) {
			$this->indentHelper = method_exists($this->view, 'plugin')
				? $this->view->plugin('Indent')
				: new Indent();
		}

		return $this->indentHelper;
	}

	/**
	 * Renderira element.
	 *
	 * @param ElementInterface $element Multicheckbox element.
	 *
	 * @return string
	 */
	public function render(ElementInterface $element)
	{
		if (!$element instanceof MultiCheckbox) {
			throw new \InvalidArgumentException(sprintf(
				'%s requires that the element is of type Zend\Form\Element\MultiCheckbox',
				__METHOD__
			));
		}

		$name = static::getName($element);

		$options = $element->getValueOptions();

		$attributes = $element->getAttributes();
		$attributes['name'] = $name;
		$attributes['type'] = $this->getInputType();
		$selectedOptions = (array)$element->getValue();

		$rendered = $this->renderOptions($element, $options, $selectedOptions, $attributes);

		// Render hidden element
		$useHiddenElement = method_exists($element, 'useHiddenElement') && $element->useHiddenElement()
			? $element->useHiddenElement()
			: $this->useHiddenElement;

		if ($useHiddenElement) {
			$rendered = $this->renderHiddenElement($element, $attributes) . $rendered;
		}

		return $rendered;
	}

	/**
	 * Renderira opcije.
	 *
	 * @param MultiCheckbox $element         Element čije opcije renderiramo.
	 * @param array         $options         Opcije.
	 * @param array         $selectedOptions Trenutno odabrane opcije.
	 * @param array         $attributes      Atributi
	 *
	 * @return string
	 */
	protected function renderOptions(MultiCheckbox $element, array $options, array $selectedOptions, array $attributes)
	{
		$indentHelper = $this->getIndentHelper();

		$escapeHtmlHelper = $this->getEscapeHtmlHelper();
		$labelHelper = $this->getLabelHelper();
		$labelClose = $labelHelper->closeTag();
		$labelPosition = $this->getLabelPosition();
		$gLabelAttributes = [];

		if ($element instanceof LabelAwareInterface) {
			$gLabelAttributes = $element->getLabelAttributes();
		}

		if (empty($gLabelAttributes)) {
			$gLabelAttributes = $this->labelAttributes;
		}

		$combinedMarkup = [];
		$count = 0;

		foreach ($options as $key => $optionSpec) {
			$count++;
			if ($count > 1 && array_key_exists('id', $attributes)) {
				unset($attributes['id']);
			}

			$value = '';
			$label = '';
			$inputAttributes = $attributes;
			$labelAttributes = $gLabelAttributes;
			$selected = (isset($inputAttributes['selected'])
			             && $inputAttributes['type'] != 'radio'
			             && $inputAttributes['selected']
			);
			$disabled = (isset($inputAttributes['disabled']) && $inputAttributes['disabled']);

			if (is_scalar($optionSpec)) {
				$optionSpec = [
					'label' => $optionSpec,
					'value' => $key
				];
			}

			if (isset($optionSpec['value'])) {
				$value = $optionSpec['value'];
			}
			if (isset($optionSpec['label'])) {
				$label = $optionSpec['label'];
			}
			if (isset($optionSpec['selected'])) {
				$selected = $optionSpec['selected'];
			}
			if (isset($optionSpec['disabled'])) {
				$disabled = $optionSpec['disabled'];
			}
			if (isset($optionSpec['label_attributes'])) {
				$labelAttributes = (isset($labelAttributes))
					? array_merge($labelAttributes, $optionSpec['label_attributes'])
					: $optionSpec['label_attributes'];
			}
			if (isset($optionSpec['attributes'])) {
				$inputAttributes = array_merge($inputAttributes, $optionSpec['attributes']);
			}

			if (in_array($value, $selectedOptions)) {
				$selected = true;
			}

			$inputAttributes['value'] = $value;
			$inputAttributes['checked'] = $selected;
			$inputAttributes['disabled'] = $disabled;
			$inputAttributes['class'] = 'form-check-input';

			$input = $indentHelper(sprintf('<input %s>', $this->createAttributesString($inputAttributes))) . PHP_EOL;

			if (!$element instanceof LabelAwareInterface || !$element->getLabelOption('disable_html_escape')) {
				$label = $escapeHtmlHelper($label);
			}

			$label = $indentHelper($label) . PHP_EOL;

			$labelAttributes['class'] = 'form-check-label';

			$labelOpen = $labelHelper->openTag($labelAttributes);
			$template = $labelOpen . PHP_EOL . '%s%s' . $labelClose;
			switch ($labelPosition) {
				case self::LABEL_PREPEND:
					$markup = sprintf($template, $label, $input);
					break;
				case self::LABEL_APPEND:
				default:
					$markup = sprintf($template, $input, $label);
					break;
			}

			$markup = PHP_EOL . $indentHelper($markup) . PHP_EOL;

			$combinedMarkup[] = sprintf('<div class="form-check">%s</div>', $markup);
		}

		$hidden = sprintf('<input type="hidden" name="%s[]" value="">', $element->getName());

		return $hidden . PHP_EOL . implode(PHP_EOL . PHP_EOL, $combinedMarkup);
	}
}