<?php
namespace Ep\Gath\Entity;

/**
 * Predtavlja stanje zalihe i cijenu za neki proizvod.
 *
 * @package Ep\Gath\Entity
 * @author Elektronika Perhoč <support@ep.hr>
 * @link https://bitbucket.org/elektronika-perhoc/ep-webshop
 */
class Price
{
	/** @var string */
	private $sku;
	/** @var float */
	private $taxRate;
	/** @var float */
	private $priceRetail;
	/** @var float */
	private $priceWholesale;
	/** @var Discount */
	private $discount;
	/** @var Discount[] */
	private $discounts = [];
	/** @var Rebate */
	private $rebate;

	/**
	 * Vraća šifru proizvoda.
	 *
	 * @return string
	 */
	public function getSku(): string
	{
		return $this->sku;
	}

	/**
	 * Vraća poreznu stopu proizvoda.
	 *
	 * @return float
	 */
	public function getTaxRate(): float
	{
		return $this->taxRate;
	}

	/**
	 * Vraća maloprodajnu cijenu.
	 *
	 * @return float
	 */
	public function getPriceRetail(): float
	{
		return floatval($this->priceRetail);
	}

	/**
	 * Vraća veleprodajnu cijenu.
	 *
	 * @return float
	 */
	public function getPriceWholesale(): float
	{
		return $this->hasRebate() ? $this->getRebate()->getOriginalPrice() : $this->priceWholesale;
	}

	/**
	 * @return bool
	 */
	public function hasRebate(): bool
	{
		return null !== $this->rebate;
	}

	/**
	 * @return Rebate|null
	 */
	public function getRebate(): ?Rebate
	{
		return $this->rebate;
	}

	/**
	 * Vraća true ako ova cijena ima popust.
	 *
	 * @return bool
	 */
	public function hasDiscount(): bool
	{
		return count($this->discounts) > 0;
	}

	/**
	 * Vraća najveći popust primjenjiv na ove cijene.
	 *
	 * @return Discount|null
	 */
	public function getDiscount(): ?Discount
	{
		if (null === $this->discount && $this->hasDiscount()) {
			foreach ($this->discounts as $discount) {
				if (null === $this->discount || $discount->getDiscountedPrice() < $this->discount->getDiscountedPrice()) {
					$this->discount = $discount;
				}
			}
		}

		return $this->discount;
	}
}