<?php
namespace Ep\View;

use Twig_Environment;
use Twig_Loader_Filesystem;
use Zend\ServiceManager\Factory\InvokableFactory;
use Zend\View\HelperPluginManager;

/**
 * Twig Templating Engine
 *
 * @package Ep\Twig
 * @author Elektronika Perhoč <support@ep.hr>
 * @link https://bitbucket.org/elektronika-perhoc/ep-webshop
 */
class ConfigProvider
{
	/**
	 * Vraća konfiguraciju modula.
	 *
	 * @return array
	 */
	public function __invoke()
	{
		return [
			'dependencies' => $this->getDependencyConfig(),
			'view_helpers' => [
				'aliases' => [
					'action' => Helper\Action::class,
					'Action' => Helper\Action::class,
				],
				'factories' => [
					Helper\Action::class => InvokableFactory::class,
				],
			],

			'twig' => [
				'options' => [
					'debug' => false,
					'charset' => 'UTF-8',
					'base_template_class' => 'Twig_Template',
					'strict_variables' => false,
					'autoescape' => 'html',
					'cache' => false,
					'auto_reload' => null,
					'optimizations' => -1,
				],

				'paths' => [],
			],
		];
	}

	/**
	 * Vraća registrirane servise.
	 *
	 * @return array
	 */
	public function getDependencyConfig()
	{
		return [
			'aliases' => [
				'Twig' => Twig_Environment::class,
				'TwigLoader' => Twig_Loader_Filesystem::class,
				'ViewHelperManager' => HelperPluginManager::class,
				'ViewRenderer' => ViewRenderer::class,
			],

			'factories' => [
				Twig_Environment::class => TwigFactory::class,
				Twig_Loader_Filesystem::class => TwigLoaderFactory::class,
				HelperPluginManager::class => HelperPluginManagerFactory::class,
				ViewRenderer::class => ViewRendererFactory::class,
			],
		];
	}
}