<?php
namespace Ep\View;

use Twig_Extension;
use Twig_Function;
use Zend\View\HelperPluginManager;

/**
 * Class HelperExtension
 *
 * @package Ep\View
 * @author Elektronika Perhoč <support@ep.hr>
 * @link https://bitbucket.org/elektronika-perhoc/ep-webshop
 */
class HelperExtension extends Twig_Extension
{
	/** @var HelperPluginManager */
	protected $helpers;

	/**
	 * HelperExtension constructor.
	 *
	 * @param HelperPluginManager $helpers
	 */
	public function __construct(HelperPluginManager $helpers)
	{
		$this->helpers = $helpers;
	}

	/**
	 * Vraća registrirane Twig funkcije.
	 *
	 * @return array
	 */
	public function getFunctions()
	{
		return [
			new Twig_Function('*', [$this, 'helperProxy'], ['is_safe' => ['all']]),
		];
	}

	/**
	 * Poziva traženi ViewHelper.
	 *
	 * @return mixed
	 */
	public function helperProxy()
	{
		$args = func_get_args();
		$name = array_shift($args);

		$helper = $this->helpers->get($name);
		return call_user_func_array($helper, $args);
	}
}