<?php
namespace Ep\View;

use Interop\Container\ContainerInterface;
use Twig_Environment;
use Zend\ServiceManager\Factory\FactoryInterface;
use Zend\View\HelperPluginManager;

/**
 * Stvara novu instancu Twig templating enginea.
 *
 * @package Ep\View
 * @author Elektronika Perhoč <support@ep.hr>
 * @link https://bitbucket.org/elektronika-perhoc/ep-webshop
 */
class TwigFactory implements FactoryInterface
{
	/**
	 * Stvara objekt.
	 *
	 * @param  ContainerInterface $container
	 * @param  string $requestedName
	 * @param  null|array $options
	 *
	 * @return Twig_Environment
	 */
	public function __invoke(ContainerInterface $container, $requestedName, array $options = null)
	{
		$loader = $container->get('TwigLoader');
		$config = $container->get('config')['twig'];

		$twig = new Twig_Environment($loader, $config['options']);

		// TODO: Raspetljati cijeli ovaj dio, možda ekstenziju dodati negdje drugdje
		/** @var HelperPluginManager $helpers */
		$helpers = $container->get('ViewHelperManager');
		$renderer = new ViewRenderer($twig, $helpers);
		$helpers->setRenderer($renderer);
		$twig->addExtension(new HelperExtension($helpers));

		foreach (['__', '_x'] as $func) {
		    $twig->addFunction(new \Twig_Function($func, $func));
        }

		return $twig;
	}
}