<?php
namespace Ep\View;

use Interop\Container\ContainerInterface;
use Twig_Loader_Filesystem;
use Zend\ServiceManager\Exception\ServiceNotCreatedException;
use Zend\ServiceManager\Factory\FactoryInterface;

/**
 * Stvara novu instancu loadera za Twig.
 *
 * @package Ep\View
 * @author Elektronika Perhoč <support@ep.hr>
 * @link https://bitbucket.org/elektronika-perhoc/ep-webshop
 */
class TwigLoaderFactory implements FactoryInterface
{
    /**
     * Stvara objekt.
     *
     * @param  ContainerInterface $container
     * @param  string $requestedName
     * @param  null|array $options
     *
     * @return Twig_Loader_Filesystem
     */
    public function __invoke(ContainerInterface $container, $requestedName, array $options = null)
    {
        $config = $container->get('config')['twig'];
        $loader = new Twig_Loader_Filesystem();

        $paths = isset($config['template_paths'])
            ? $config['template_paths']
            : $config['paths'] ?? [];

        $paths = apply_filters('ep/twig/paths', $paths);

        foreach ($paths as $namespace => $path) {
            if (!is_dir($path)) {
                throw new ServiceNotCreatedException(sprintf(
                    "Nepostojeća putanja '%s'.", $path
                ));
            }

            $namespace = is_numeric($namespace) ? Twig_Loader_Filesystem::MAIN_NAMESPACE : $namespace;
            $loader->prependPath($path, $namespace);
        }

        return $loader;
    }
}