<?php
namespace EpTest\Gath\Hydrator;

use Ep\Gath\Entity\Discount;
use Ep\Gath\Entity\Price;
use EpTest\IntegrationTestCase;

class PriceHydratorTest extends IntegrationTestCase
{
	public function testCanHydrateObject()
	{
		$data = [
			'ProductCode' => '00052',
			'TaxRate' => 25,
			'PriceRetail' => 36,
			'PriceWholesale' => 28.8,
			'Stock' => 104.45,
			'Discount' => [[
				'Rate' => 30,
				'Original' => 36,
				'New' => 25.2,
				'ValidTill' => '2017-12-31 00:00:00.000',
			]],
			'RabPolicy' => [[
				'Rate' => 28,
				'CalculatedNetto' => 12.23
			]],
		];

		$hydrator = $this->getHydrator(Price::class);
		/** @var Price $object */
		$object = $hydrator->hydrate($data, new Price());

		$this->assertEquals('00052', $object->getSku());
		$this->assertEquals(25, $object->getTaxRate());
		$this->assertEquals(36, $object->getPriceRetail());
		$this->assertEquals(28.8, $object->getPriceWholesale());
		$this->assertTrue($object->hasRebate());
		$this->assertEquals(28, $object->getRebate()->getRate());
		$this->assertEquals(12.23, $object->getRebate()->getDiscountedPrice());

		$discount = $object->getDiscount();
		$this->assertInstanceOf(Discount::class, $discount);
		$this->assertEquals(25.2, $discount->getDiscountedPrice());


	}
}